@@ -1,4 +1,4 @@
-#' Formatting Functions
+#' Formatting functions
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -11,14 +11,14 @@
 #' @name formatting_functions
 NULL
 
-#' Formatting Fraction and Percentage
+#' Format fraction and percentage
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' Formats a fraction together with ratio in percent.
 #'
-#' @param x (`integer`)\cr with elements `num` and `denom`.
-#' @param ... required for `rtables` interface.
+#' @param x (named `integer`)\cr vector with elements `num` and `denom`.
+#' @param ... not used. Required for `rtables` interface.
 #'
 #' @return A string in the format `num / denom (ratio %)`. If `num` is 0, the format is `num / denom`.
 #'
@@ -47,15 +47,14 @@ format_fraction <- function(x, ...) {
   return(result)
 }
 
-#' Formatting Fraction and Percentage with Fixed Single Decimal Place
+#' Format fraction and percentage with fixed single decimal place
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' Formats a fraction together with ratio in percent with fixed single decimal place.
 #' Includes trailing zero in case of whole number percentages to always keep one decimal place.
 #'
-#' @param x (`integer`)\cr with elements `num` and `denom`.
-#' @param ... required for `rtables` interface.
+#' @inheritParams format_fraction
 #'
 #' @return A string in the format `num / denom (ratio %)`. If `num` is 0, the format is `num / denom`.
 #'
@@ -83,14 +82,14 @@ format_fraction_fixed_dp <- function(x, ...) {
   return(result)
 }
 
-#' Formatting Count and Fraction
+#' Format count and fraction
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' Formats a count together with fraction with special consideration when count is `0`.
 #'
-#' @param x (`integer`)\cr vector of length 2, count and fraction.
-#' @param ... required for `rtables` interface.
+#' @param x (`numeric(2)`)\cr vector of length 2 with count and fraction, respectively.
+#' @param ... not used. Required for `rtables` interface.
 #'
 #' @return A string in the format `count (fraction %)`. If `count` is 0, the format is `0`.
 #'
@@ -120,14 +119,13 @@ format_count_fraction <- function(x, ...) {
   return(result)
 }
 
-#' Formatting Count and Percentage with Fixed Single Decimal Place
+#' Format count and percentage with fixed single decimal place
 #'
 #' @description `r lifecycle::badge("experimental")`
 #'
 #' Formats a count together with fraction with special consideration when count is `0`.
 #'
-#' @param x (`integer`)\cr vector of length 2, count and fraction.
-#' @param ... required for `rtables` interface.
+#' @inheritParams format_count_fraction
 #'
 #' @return A string in the format `count (fraction %)`. If `count` is 0, the format is `0`.
 #'
@@ -151,7 +149,7 @@ format_count_fraction_fixed_dp <- function(x, ...) {
 
   result <- if (x[1] == 0) {
     "0"
-  } else if (x[2] == 1) {
+  } else if (.is_equal_float(x[2], 1)) {
     sprintf("%d (100%%)", x[1])
   } else {
     sprintf("%d (%.1f%%)", x[1], x[2] * 100)
@@ -160,7 +158,7 @@ format_count_fraction_fixed_dp <- function(x, ...) {
   return(result)
 }
 
-#' Formatting Count and Fraction with Special Case for Count < 10
+#' Format count and fraction with special case for count < 10
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -197,7 +195,7 @@ format_count_fraction_lt10 <- function(x, ...) {
   return(result)
 }
 
-#' Formatting: XX as Formatting Function
+#' Format XX as a formatting function
 #'
 #' Translate a string where x and dots are interpreted as number place
 #' holders, and others as formatting elements.
@@ -246,15 +244,15 @@ format_xx <- function(str) {
   return(rtable_format)
 }
 
-#' Formatting Numeric Values By Significant Figures
+#' Format numeric values by significant figures
 #'
 #' Format numeric values to print with a specified number of significant figures.
 #'
-#' @param sigfig (`integer`)\cr number of significant figures to display.
-#' @param format (`character`)\cr the format label (string) to apply when printing the value. Decimal
+#' @param sigfig (`integer(1)`)\cr number of significant figures to display.
+#' @param format (`string`)\cr the format label (string) to apply when printing the value. Decimal
 #'   places in string are ignored in favor of formatting by significant figures. Formats options are:
 #'   `"xx"`, `"xx / xx"`, `"(xx, xx)"`, `"xx - xx"`, and `"xx (xx)"`.
-#' @param num_fmt (`character`)\cr numeric format modifiers to apply to the value. Defaults to `"fg"` for
+#' @param num_fmt (`string`)\cr numeric format modifiers to apply to the value. Defaults to `"fg"` for
 #'   standard significant figures formatting - fixed (non-scientific notation) format (`"f"`)
 #'   and `sigfig` equal to number of significant figures instead of decimal places (`"g"`). See the
 #'   [formatC()] `format` argument for more options.
@@ -285,7 +283,7 @@ format_sigfig <- function(sigfig, format = "xx", num_fmt = "fg") {
   }
 }
 
-#' Formatting Fraction with Lower Threshold
+#' Format fraction with lower threshold
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -324,13 +322,13 @@ format_fraction_threshold <- function(threshold) {
   }
 }
 
-#' Formatting Extreme Values
+#' Format extreme values
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
 #' `rtables` formatting functions that handle extreme values.
 #'
-#' @param digits (`integer`)\cr number of decimal places to display.
+#' @param digits (`integer(1)`)\cr number of decimal places to display.
 #'
 #' @details For each input, apply a format to the specified number of `digits`. If the value is
 #'    below a threshold, it returns "<0.01" e.g. if the number of `digits` is 2. If the value is
@@ -370,7 +368,7 @@ h_get_format_threshold <- function(digits = 2L) {
 #' @describeIn extreme_format Internal helper function to apply a threshold format to a value.
 #'   Creates a formatted string to be used in Formatting Functions.
 #'
-#' @param x (`number`)\cr value to format.
+#' @param x (`numeric(1)`)\cr value to format.
 #'
 #' @return
 #' * `h_format_threshold()` returns the given value, or if the value is not within the digit threshold the relation
@@ -401,11 +399,11 @@ h_format_threshold <- function(x, digits = 2L) {
   unname(result)
 }
 
-#' Formatting a Single Extreme Value
+#' Format a single extreme value
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
-#' Create Formatting Function for a single extreme value.
+#' Create a formatting function for a single extreme value.
 #'
 #' @inheritParams extreme_format
 #'
@@ -428,7 +426,7 @@ format_extreme_values <- function(digits = 2L) {
   }
 }
 
-#' Formatting Extreme Values Part of a Confidence Interval
+#' Format extreme values part of a confidence interval
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -457,7 +455,7 @@ format_extreme_values_ci <- function(digits = 2L) {
   }
 }
 
-#' Automatic formats from data significant digits
+#' Format automatically using data significant digits
 #'
 #' @description `r lifecycle::badge("stable")`
 #'
@@ -467,11 +465,11 @@ format_extreme_values_ci <- function(digits = 2L) {
 #' This function can be called internally with "auto" like, for example,
 #' `.formats = c("mean" = "auto")`. See details to see how this works with the inner function.
 #'
-#' @param dt_var (`numeric`) \cr all the data the statistics was created upon. Used only to find
-#'   significant digits. In [analyze_vars] this comes from `.df_row` (see
+#' @param dt_var (`numeric`)\cr variable data the statistics were calculated from. Used only to
+#'   find significant digits. In [analyze_vars] this comes from `.df_row` (see
 #'   [rtables::additional_fun_params]), and it is the row data after the above row splits. No
 #'   column split is considered.
-#' @param x_stat (`string`) \cr string indicating the current statistical method used.
+#' @param x_stat (`string`)\cr string indicating the current statistical method used.
 #'
 #' @return A string that `rtables` prints in a table cell.
 #'
@@ -549,14 +547,16 @@ str_extract <- function(string, pattern = "xx|xx\\.|xx\\.x+", invert = FALSE) {
 
 # Helper function
 count_decimalplaces <- function(dec) {
-  if (abs(dec - round(dec)) > .Machine$double.eps^0.5) { # For precision
+  if (is.na(dec)) {
+    return(0)
+  } else if (abs(dec - round(dec)) > .Machine$double.eps^0.5) { # For precision
     nchar(strsplit(format(dec, scientific = FALSE, trim = FALSE), ".", fixed = TRUE)[[1]][[2]])
   } else {
     return(0)
   }
 }
 
-#' Apply Auto Formatting
+#' Apply automatic formatting
 #'
 #' Checks if any of the listed formats in `.formats` are `"auto"`, and replaces `"auto"` with
 #' the correct implementation of `format_auto` for the given statistics, data, and variable.
