@@ -107,7 +107,7 @@ testthat::test_that("get_labels_from_stats works as expected", {
   res <- testthat::expect_silent(get_labels_from_stats(sts))
   testthat::expect_snapshot(res)
 
-  testthat::expect_identical(get_labels_from_stats(c("nothing", "n"))[["nothing"]], "")
+  testthat::expect_identical(get_labels_from_stats(c("nothing", "n"))[["nothing"]], "nothing")
 
   testthat::expect_identical(
     get_labels_from_stats(c("nothing", "unique"))[["unique"]],
@@ -199,22 +199,24 @@ testthat::test_that("labels_use_control works as expected", {
 })
 
 testthat::test_that("summary_formats works as expected", {
-  result <- summary_formats() %>%
-    unlist() # More compact fruition
+  testthat::expect_warning(
+    result <- summary_formats() %>%
+      unlist() # More compact fruition
+  )
   res <- testthat::expect_silent(result)
   testthat::expect_snapshot(res)
 
-  result <- summary_formats(type = "counts", include_pval = TRUE)
+  testthat::expect_warning(result <- summary_formats(type = "counts", include_pval = TRUE))
   testthat::expect_true(all(result[c("n", "count", "n_blq")] == "xx."))
   testthat::expect_identical(result[["pval_counts"]], "x.xxxx | (<0.0001)")
 })
 
 testthat::test_that("summary_labels works as expected", {
-  result <- summary_labels()
+  testthat::expect_warning(result <- summary_labels())
   res <- testthat::expect_silent(result)
   testthat::expect_snapshot(res)
 
-  result <- summary_labels(type = "counts", include_pval = TRUE)
+  testthat::expect_warning(result <- summary_labels(type = "counts", include_pval = TRUE))
   res <- testthat::expect_silent(result)
   testthat::expect_snapshot(res)
 })
